==> apache-doris-3.0.8-rc01-src.tar.gz: apache-doris-3.0.8-rc01-src/fe/fe-core/src/main/java/org/apache/doris/nereids/trees/plans/distribute/worker/job/LocalShuffleAssignedJob.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.nereids.trees.plans.distribute.worker.job;

import org.apache.doris.nereids.trees.plans.distribute.worker.DistributedPlanWorker;
import org.apache.doris.thrift.TUniqueId;

import com.google.common.collect.ImmutableMap;

import java.util.Map;

/** LocalShuffleAssignedJob */
public class LocalShuffleAssignedJob extends StaticAssignedJob {
    public final int shareScanId;

    public LocalShuffleAssignedJob(
            int indexInUnassignedJob, int shareScanId, TUniqueId instanceId,
            UnassignedJob unassignedJob,
            DistributedPlanWorker worker, ScanSource scanSource) {
        super(indexInUnassignedJob, instanceId, unassignedJob, worker, scanSource);
        this.shareScanId = shareScanId;
    }

    @Override
    protected Map<String, String> extraInfo() {
        return ImmutableMap.of("shareScanIndex", String.valueOf(shareScanId));
    }
}

==> apache-doris-4.0.0-rc02-src.tar.gz: apache-doris-4.0.0-rc02-src/fe/fe-core/src/main/java/org/apache/doris/nereids/trees/plans/distribute/worker/job/LocalShuffleAssignedJob.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.nereids.trees.plans.distribute.worker.job;

import org.apache.doris.nereids.trees.plans.distribute.worker.DistributedPlanWorker;
import org.apache.doris.thrift.TUniqueId;

import com.google.common.collect.ImmutableMap;

import java.util.Map;

/**
 * LocalShuffleAssignedJob:
 *   this instance will use ignore_data_distribution function of local shuffle to add parallel
 *   after scan data
 */
public class LocalShuffleAssignedJob extends StaticAssignedJob {
    public final int shareScanId;

    public LocalShuffleAssignedJob(
            int indexInUnassignedJob, int shareScanId, TUniqueId instanceId,
            UnassignedJob unassignedJob,
            DistributedPlanWorker worker, ScanSource scanSource) {
        super(indexInUnassignedJob, instanceId, unassignedJob, worker, scanSource);
        this.shareScanId = shareScanId;
    }

    @Override
    protected Map<String, String> extraInfo() {
        return ImmutableMap.of("shareScanIndex", String.valueOf(shareScanId));
    }
}
